# python3-lib

The microservice-libary for python3 of cryptic-game.

Pypi Seite: https://pypi.org/project/microservicecryp/

## Installation:

```bash
$ pip3 install microservicecryp
```

## Quick-Start

Lock into the [example.py](https://github.com/cryptic-game/python3-lib/blob/master/example.py). Its an easy echo-microservice.

## Requirements

Required are all modules in the `requirements.txt`.

## Test it!

Your microservice will be supported by the [game-server of cryptic](https://github.com/cryptic-game/server).

### Environment variables

| key               | default value |
|-------------------|---------------|
| MSSOCKET_HOST     | 127.0.0.1     |
| MSSOCKET_PORT     | 1239          |

## Wiki

Visit our [wiki](https://github.com/cryptic-game/python3-lib/wiki) for more information.
